Certificates | OiRA
Description: Depending on the approach taken by the national OiRA partner/tool developer, it may be possible to obtain a certificate for your risk assessment. For details about the advantages of such certificates, please contact your national OiRA partner.

Topics

# Certificates

Depending on the approach taken by the national OiRA partner/tool developer, it may be possible to obtain a certificate for your risk assessment. For details about the advantages of such certificates, please contact your national OiRA partner.

How to obtain a certificate

## Do a full risk assessment

As you work through your risk assessment, OiRA will record your progress. Once you have assessed a number of risks, the tool informs you about the possibility of obtaining a certificate on completion of the full risk assessment. Each national OiRA partner/tool developer sets the threshold (percentages) for how a ‘full’ risk assessment is defined. The certificate is available through the ‘Status’ button in the menu on the left of the screen.

The status page shows that a certificate is available.

## View and publish your certificate

When you click the button ‘View certificate’, you will be asked to enter the name of the company that should appear on the certificate. Depending on national settings, you may be asked to enter further data to make sure the certificate gives all the information you need to provide.

Enter all information needed for the certificate.

If you tick the box labelled ‘Make public’, a unique link (URL) to your certificate will appear. Copy this link and share it with the relevant people as proof that you have conducted your risk assessment.

Note: Only the data shown on this page will be made public. This link is not available through the menu of the OiRA website –- it is specific to you. However, theoretically anyone who browses the internet could see the certificate you have created!

The certificate shows only that you have responded to a certain number of risks in the risk assessment tool but does not give any other information. The specific answers to the risk assessment given when completing the OiRA tool can be viewed only by you and nobody else.

Scroll to top Load toolbar…
Back

## 5-certificates.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More